<?php

namespace Drupal\role_language_negotiation\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class NegotiationRoleForm.
 */
class NegotiationRoleForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'role_language_negotiation.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'negotiation_role_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('role_language_negotiation.settings')->get('language_negotiation_roles');
    $group_class = 'table-sort-weight';
    $languages = \Drupal::languageManager()->getLanguages();

    $form['vertical_tabs'] = array(
      '#type' => 'vertical_tabs',
      '#default_tab' => 'edit-publication',
    );

    foreach (user_role_names() as $role_key => $role_value) {
      $form['tab_' . $role_key] = array(
        '#type' => 'details',
        '#title' => $role_value,
        '#group' => 'vertical_tabs',
      );
      $form['tab_' . $role_key]['role_' . $role_key . '_enabled'] = [
        '#type' => 'checkbox',
        '#title' => $this->t('Enabled'),
        '#default_value' => !empty($config) ? $config[$role_key]['enabled'] : FALSE,
        '#description' => $this->t('Enable checking language for this role'),
      ];


      // Build table.
      $form['tab_' . $role_key]['tab_' . $role_key . '_container'] = [
        '#type' => 'container',
        '#states' => [
          'visible' => [
            ":input[name='role_" . $role_key . "_enabled']" => ['checked' => true],
          ]
        ],
      ];

      $form['tab_' . $role_key]['tab_' . $role_key . '_container']['role_' . $role_key . '_table'] = [
        '#type' => 'table',
        '#caption' => $this->t('Enable languages for this role (language priority depends on row weight)'),
        '#header' => [
          $this->t('Language'),
          $this->t('Enabled'),
          $this->t('Weight'),
        ],
        '#empty' => $this->t('No items.'),
        '#tabledrag' => [
          [
            'action' => 'order',
            'relationship' => 'sibling',
            'group' => $group_class,
          ]
        ],

      ];

      foreach ($languages as $key => $value) {
        $form['tab_' . $role_key]['tab_' . $role_key . '_container']['role_' . $role_key . '_table'][$key]['#attributes']['class'][] = 'draggable';
        $form['tab_' . $role_key]['tab_' . $role_key . '_container']['role_' . $role_key . '_table'][$key]['#weight'] = (int) $config[$role_key]['languages'][$key]['weight'];
        $form['tab_' . $role_key]['tab_' . $role_key . '_container']['role_' . $role_key . '_table'][$key]['language'] = [
          '#plain_text' => $value->getName(),
        ];
        $form['tab_' . $role_key]['tab_' . $role_key . '_container']['role_' . $role_key . '_table'][$key]['enabled'] = [
          '#type' => 'checkbox',
          '#default_value' => !empty($config) ? $config[$role_key]['languages'][$key]['enabled'] : FALSE,
        ];
        $form['tab_' . $role_key]['tab_' . $role_key . '_container']['role_' . $role_key . '_table'][$key]['weight'] = [
          '#type' => 'weight',
          '#title' => $this->t('Weight for @title', ['@title' => $value->getName()]),
          '#title_display' => 'invisible',
          '#default_value' => !empty($config) ? (int) $config[$role_key]['languages'][$key]['weight']: 0,
          '#attributes' => ['class' => [$group_class]],
        ];
      }
    }

    // Form action buttons.
    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $roles = [];
    foreach (user_role_names() as $role_key => $role_value) {
      $roles[$role_key] = [
        'enabled' => $values['role_' . $role_key . '_enabled'],
        'languages' => $values['role_' . $role_key . '_table'],
      ];
    }

    $config = $this->config('role_language_negotiation.settings');
    $config->set('language_negotiation_roles', $roles);
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
